@@ -72,6 +72,9 @@ struct Mtz {
     float operator[](int n) const { return parent->data[idx + n * stride()]; }
     float& at(int n) { return parent->data.at(idx + n * stride()); }
     float at(int n) const { return parent->data.at(idx + n * stride()); }
+    bool is_integer() const {
+      return type == 'H' || type == 'B' || type == 'Y' || type == 'I';
+    }
     using iterator = StrideIter<float>;
     iterator begin() {
       assert(parent);
@@ -503,7 +506,8 @@ struct Mtz {
   }
 
   void setup_spacegroup() {
-    spacegroup = find_spacegroup_by_name(spacegroup_name);
+    spacegroup = find_spacegroup_by_name(spacegroup_name,
+                                         cell.alpha, cell.gamma);
     if (!spacegroup) {
       warn("MTZ: unrecognized spacegroup name: " + spacegroup_name);
       return;
